/* abcview.h */

/*

ABC Viewer, a program to display abc format music files on the Palm Pilot.

    Copyright (C) 1998,1999  Dave Holland  dave@zenda.demon.co.uk

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#define STAVE_SEP	34 /* should be even */
#define STAVE_OFFSET	15

/* how many things on a line */
#define maxThings 14

/* max staves to handle */
#define maxStaves	10

/* max number of symbols */
#define maxSymbols	200

/* max text lines to keep track of, and their max length */
#define maxText		20
#define	maxTextLen	80

/* ABC symbols */
#define ABCCOMP -9
#define ABCEND	-10
#define ABCBAR	-11
#define ABCDBAR	-12
#define ABCRREP	-13
#define ABCLREP	-14

/* note durations */
#define BASE	192
#define WHOLE	192		/* semibreve */
#define	HALF	96		/* minim */
#define QUARTER	48		/* crotchet */
#define	EIGHTH	24		/* quaver */
#define	SIXTEENTH	12	/* semiquaver */
#define	THIRTYSECOND	6	/* demisemiquaver */

/* types of symbol */
#define	INVISIBLE	1
#define	NOTE		2
#define REST		3
#define	BARLINE		4	/* include repeats etc */
#define CLEF		5
#define TIMESIG		6
#define	KEYSIG		7
#define	TEXTLINE	8	/* a line of text (i.e. no music) */

/* different types of barline */
#define B_SINGLE	1
#define B_DOUBLE	2
#define B_LREP		3	/* |: */
#define B_RREP		4	/* :| */
#define B_LFAT		5	/* [| */
#define B_RFAT		6	/* |] */
#define B_DREP		7	/* :: */
#define B_FIRST		8
#define B_SECOND	9

/* accidentals */
#define A_NONE	0
#define	A_SH	1
#define A_NT	2
#define A_FL	3
#define A_DS	4
#define A_DF	5

/* clefs */
#define TREBLE	1
#define BASS	2
#define ALTO	3

/* stems */
#define STEM_DOWN -1
#define STEM_NONE 0
#define STEM_UP 1

#define STEM_LENGTH 12

/* length of the "tail" on isolated quavers, etc */
#define TAIL_LENGTH 4

struct SYMBOL {
	int type;	/* symbol type */
	int pitch;	/* basic pitch */
	int length; /* basic length */
	int acc;	/* accidental */
	int ti1;	/* flag to start tie here */
	int ti2;	/* flag to end tie here */
	int stem;	/* -1,0,1 => down, no, up stem */
	int dots;	/* number of dots */
	int eoln;	/* flag for last symbol in line */
	int x;		/* x offset (0-159) */
	int ti;		/* index into text array */
	int	width;	/* on-screen pixel width */
	int	stave;	/* which stave */
	int ts1;	/* time sig values */
	int ts2;
};


#define memosInCategoryUnknown  0xffff
#define noRecordSelected        -1



void Alert(CharPtr p1, CharPtr p2, CharPtr p3);
void MainViewDrawRecord(VoidPtr table, Word row, Word column,
	RectanglePtr bounds);
void MainViewLoadTable(FormPtr frm,UInt recordNum);
void MainViewLoadRecords(FormPtr frm);
void RedrawMusicForm(void);
Boolean MusicFormHandleEvent (EventPtr e);
Boolean MainFormHandleEvent (EventPtr e);
Boolean ApplicationHandleEvent(EventPtr e);
Word StartApplication(void);
void StopApplication(void);
void EventLoop(void);
DWord PilotMain(Word cmd, Ptr cmdPBP, Word launchFlags);



/* vi:ts=4:sw=4:si:nocindent
 */
